pub unsafe trait AcpiTable {
const SIGNATURE: Signature;
// Required method
fn header(&self) -> &SdtHeader;
// Provided method
fn validate(&self) -> Result<(), AcpiError> { ... }
}Expand description
All types representing ACPI tables should implement this trait.
Safety
The table’s memory is naively interpreted, so you must be careful in providing a type that
correctly represents the table’s structure. Regardless of the provided type’s size, the region mapped will
be the size specified in the SDT’s header. If a table’s definition may be larger than a valid
SDT’s size, ExtendedField should be used to define fields that may or
may not exist.
Required Associated Constants
Required Methods
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.